[−][src]Function mdbook::utils::fs::remove_dir_content
pub fn remove_dir_content(dir: &Path) -> Result<()>
Removes all the content of a directory but not the directory itself
pub fn remove_dir_content(dir: &Path) -> Result<()>
Removes all the content of a directory but not the directory itself